@@ -1,11 +1,12 @@
-#!/usr/bin/python3.10
+#!/usr/bin/python3.13
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal2xyz as a convenience to use as a script
 from osgeo_utils.gdal2xyz import *  # noqa
 from osgeo_utils.gdal2xyz import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal2xyz')
+deprecation_warn("gdal2xyz")
 sys.exit(main(sys.argv))
